@@ -1,5 +1,5 @@
 #
-# $Id: PatternTcpMss.pm,v 1.1.2.10.2.2 2006/05/31 16:49:57 gomor Exp $
+# $Id: PatternTcpMss.pm,v 1.1.2.12.2.3 2006/06/11 17:18:53 gomor Exp $
 #
 package Net::SinFP::DB::PatternTcpMss;
 use strict;
@@ -10,16 +10,21 @@ our @ISA = qw(DBIx::SQLite::Simple::Table);
 
 our @AS = qw(
    idPatternTcpMss
-   patternTcpMss
+   patternTcpMssHeuristic0
    patternTcpMssHeuristic1
    patternTcpMssHeuristic2
 );
 __PACKAGE__->cgBuildIndices;
 __PACKAGE__->cgBuildAccessorsScalar(\@AS);
 
+our $Id     = $AS[0];
+our @Fields = @AS[1..$#AS];
+
+1;
+
 =head1 NAME
 
-Net::SinFP::DB::PatternTcpMss - PatternTcpMss SQL table
+Net::SinFP::DB::PatternTcpMss - PatternTcpMss database table
 
 =head1 DESCRIPTION
 
@@ -27,17 +32,6 @@ Go to http://www.gomor.org/sinfp to know more.
 
 =cut
 
-our $Id     = qw(idPatternTcpMss);
-our @Fields = qw(patternTcpMss patternTcpMssHeuristic1 patternTcpMssHeuristic2);
-
-sub getTcpMss { shift->lookupString('patternTcpMss', idPatternTcpMss => shift) }
-sub getTcpMssH1 {
-   shift->lookupString('patternTcpMssHeuristic1', idPatternTcpMss => shift);
-}
-sub getTcpMssH2 {
-   shift->lookupString('patternTcpMssHeuristic2', idPatternTcpMss => shift);
-}
-
 =head1 AUTHOR
 
 Patrice E<lt>GomoRE<gt> Auffret
@@ -50,5 +44,3 @@ You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
 
 =cut
-
-1;
